resource "aws_vpc" "example_vn_aws" {
  provider             = "aws.eu-west-1"
  tags                 = { "Name" = "example_vn" }
  cidr_block           = "10.0.0.0/16"
  enable_dns_hostnames = true
}
resource "aws_internet_gateway" "example_vn_aws" {
  provider = "aws.eu-west-1"
  tags     = { "Name" = "example_vn" }
  vpc_id   = aws_vpc.example_vn_aws.id
}
resource "aws_default_security_group" "example_vn_aws" {
  provider = "aws.eu-west-1"
  tags     = { "Name" = "example_vn" }
  vpc_id   = aws_vpc.example_vn_aws.id
  ingress {
    protocol  = "-1"
    from_port = 0
    to_port   = 0
    self      = true
  }
  egress {
    protocol  = "-1"
    from_port = 0
    to_port   = 0
    self      = true
  }
}
resource "azurerm_virtual_network" "example_vn_azure" {
  resource_group_name = azurerm_resource_group.rg1.name
  name                = "example_vn"
  location            = "northeurope"
  address_space       = ["10.0.0.0/16"]
}
resource "azurerm_route_table" "example_vn_azure" {
  resource_group_name = azurerm_resource_group.rg1.name
  name                = "example_vn"
  location            = "northeurope"
  route {
    name           = "local"
    address_prefix = "0.0.0.0/0"
    next_hop_type  = "VnetLocal"
  }
}
resource "azurerm_resource_group" "rg1" {
  name     = "rg1"
  location = "northeurope"
}
resource "aws_subnet" "subnet_aws" {
  provider          = "aws.eu-west-1"
  tags              = { "Name" = "subnet" }
  cidr_block        = "10.0.2.0/24"
  vpc_id            = aws_vpc.example_vn_aws.id
  availability_zone = "eu-west-1b"
}
resource "azurerm_subnet" "subnet_azure" {
  resource_group_name  = azurerm_resource_group.rg1.name
  name                 = "subnet"
  address_prefixes     = ["10.0.2.0/24"]
  virtual_network_name = azurerm_virtual_network.example_vn_azure.name
}
resource "azurerm_subnet_route_table_association" "subnet_azure" {
  subnet_id      = azurerm_subnet.subnet_azure.id
  route_table_id = azurerm_route_table.example_vn_azure.id
}
resource "aws_iam_instance_profile" "vm2_aws" {
  provider = "aws.eu-west-1"
  name     = "multy-vm-vm2_aws-role"
  role     = aws_iam_role.vm2_aws.name
}
resource "aws_iam_role" "vm2_aws" {
  provider           = "aws.eu-west-1"
  tags               = { "Name" = "test-vm" }
  name               = "multy-vm-vm2_aws-role"
  assume_role_policy = "{\"Statement\":[{\"Action\":[\"sts:AssumeRole\"],\"Effect\":\"Allow\",\"Principal\":{\"Service\":\"ec2.amazonaws.com\"}}],\"Version\":\"2012-10-17\"}"
}
data "aws_ami" "vm2_aws" {
  provider    = "aws.eu-west-1"
  owners      = ["136693071363"]
  most_recent = true
  filter {
    name   = "name"
    values = ["debian-10-amd64-*"]
  }
  filter {
    name   = "root-device-type"
    values = ["ebs"]
  }
  filter {
    name   = "virtualization-type"
    values = ["hvm"]
  }
}
resource "aws_instance" "vm2_aws" {
  provider             = "aws.eu-west-1"
  tags                 = { "Name" = "test-vm" }
  ami                  = data.aws_ami.vm2_aws.id
  instance_type        = "t2.nano"
  subnet_id            = aws_subnet.subnet_aws.id
  iam_instance_profile = aws_iam_instance_profile.vm2_aws.id
}
resource "azurerm_network_interface" "vm2_azure" {
  resource_group_name = azurerm_resource_group.rg1.name
  name                = "test-vm"
  location            = "northeurope"
  ip_configuration {
    name                          = "internal"
    private_ip_address_allocation = "Dynamic"
    subnet_id                     = azurerm_subnet.subnet_azure.id
    primary                       = true
  }
}
resource "random_password" "vm2_azure" {
  length  = 16
  special = true
  upper   = true
  lower   = true
  number  = true
}
resource "azurerm_linux_virtual_machine" "vm2_azure" {
  resource_group_name   = azurerm_resource_group.rg1.name
  name                  = "test-vm"
  location              = "northeurope"
  size                  = "Standard_B1ls"
  network_interface_ids = [azurerm_network_interface.vm2_azure.id]
  os_disk {
    caching              = "None"
    storage_account_type = "Standard_LRS"
  }
  admin_username = "adminuser"
  admin_password = random_password.vm2_azure.result
  source_image_reference {
    publisher = "Debian"
    offer     = "debian-10"
    sku       = "10"
    version   = "latest"
  }
  disable_password_authentication = false
  identity {
    type = "SystemAssigned"
  }
  computer_name = "testvm"
}
resource "aws_iam_instance_profile" "vm3_aws" {
  provider = "aws.eu-west-1"
  name     = "multy-vm-vm3_aws-role"
  role     = aws_iam_role.vm3_aws.name
}
resource "aws_iam_role" "vm3_aws" {
  provider           = "aws.eu-west-1"
  tags               = { "Name" = "test-vm" }
  name               = "multy-vm-vm3_aws-role"
  assume_role_policy = "{\"Statement\":[{\"Action\":[\"sts:AssumeRole\"],\"Effect\":\"Allow\",\"Principal\":{\"Service\":\"ec2.amazonaws.com\"}}],\"Version\":\"2012-10-17\"}"
}
data "aws_ami" "vm3_aws" {
  provider    = "aws.eu-west-1"
  owners      = ["125523088429"]
  most_recent = true
  filter {
    name   = "name"
    values = ["CentOS 8.2* x86_64"]
  }
  filter {
    name   = "root-device-type"
    values = ["ebs"]
  }
  filter {
    name   = "virtualization-type"
    values = ["hvm"]
  }
}
resource "aws_instance" "vm3_aws" {
  provider             = "aws.eu-west-1"
  tags                 = { "Name" = "test-vm" }
  ami                  = data.aws_ami.vm3_aws.id
  instance_type        = "t2.nano"
  subnet_id            = aws_subnet.subnet_aws.id
  iam_instance_profile = aws_iam_instance_profile.vm3_aws.id
}
resource "azurerm_network_interface" "vm3_azure" {
  resource_group_name = azurerm_resource_group.rg1.name
  name                = "test-vm"
  location            = "northeurope"
  ip_configuration {
    name                          = "internal"
    private_ip_address_allocation = "Dynamic"
    subnet_id                     = azurerm_subnet.subnet_azure.id
    primary                       = true
  }
}
resource "random_password" "vm3_azure" {
  length  = 16
  special = true
  upper   = true
  lower   = true
  number  = true
}
resource "azurerm_linux_virtual_machine" "vm3_azure" {
  resource_group_name   = azurerm_resource_group.rg1.name
  name                  = "test-vm"
  location              = "northeurope"
  size                  = "Standard_B1ls"
  network_interface_ids = [azurerm_network_interface.vm3_azure.id]
  os_disk {
    caching              = "None"
    storage_account_type = "Standard_LRS"
  }
  admin_username = "adminuser"
  admin_password = random_password.vm3_azure.result
  source_image_reference {
    publisher = "OpenLogic"
    offer     = "CentOs"
    sku       = "8_2"
    version   = "latest"
  }
  disable_password_authentication = false
  identity {
    type = "SystemAssigned"
  }
  computer_name = "testvm"
}
resource "aws_iam_instance_profile" "vm_aws" {
  provider = "aws.eu-west-1"
  name     = "multy-vm-vm_aws-role"
  role     = aws_iam_role.vm_aws.name
}
resource "aws_iam_role" "vm_aws" {
  provider           = "aws.eu-west-1"
  tags               = { "Name" = "test-vm" }
  name               = "multy-vm-vm_aws-role"
  assume_role_policy = "{\"Statement\":[{\"Action\":[\"sts:AssumeRole\"],\"Effect\":\"Allow\",\"Principal\":{\"Service\":\"ec2.amazonaws.com\"}}],\"Version\":\"2012-10-17\"}"
}
data "aws_ami" "vm_aws" {
  provider    = "aws.eu-west-1"
  owners      = ["099720109477"]
  most_recent = true
  filter {
    name   = "name"
    values = ["ubuntu*-18.04-amd64-server-*"]
  }
  filter {
    name   = "root-device-type"
    values = ["ebs"]
  }
  filter {
    name   = "virtualization-type"
    values = ["hvm"]
  }
}
resource "aws_instance" "vm_aws" {
  provider             = "aws.eu-west-1"
  tags                 = { "Name" = "test-vm" }
  ami                  = data.aws_ami.vm_aws.id
  instance_type        = "t2.nano"
  subnet_id            = aws_subnet.subnet_aws.id
  user_data_base64     = "ZWNobyAnSGVsbG8gV29ybGQn"
  iam_instance_profile = aws_iam_instance_profile.vm_aws.id
}
resource "azurerm_network_interface" "vm_azure" {
  resource_group_name = azurerm_resource_group.rg1.name
  name                = "test-vm"
  location            = "northeurope"
  ip_configuration {
    name                          = "internal"
    private_ip_address_allocation = "Dynamic"
    subnet_id                     = azurerm_subnet.subnet_azure.id
    primary                       = true
  }
}
resource "random_password" "vm_azure" {
  length  = 16
  special = true
  upper   = true
  lower   = true
  number  = true
}
resource "azurerm_linux_virtual_machine" "vm_azure" {
  resource_group_name   = azurerm_resource_group.rg1.name
  name                  = "test-vm"
  location              = "northeurope"
  size                  = "Standard_B1ls"
  network_interface_ids = [azurerm_network_interface.vm_azure.id]
  custom_data           = "ZWNobyAnSGVsbG8gV29ybGQn"
  os_disk {
    caching              = "None"
    storage_account_type = "Standard_LRS"
  }
  admin_username = "adminuser"
  admin_password = random_password.vm_azure.result
  source_image_reference {
    publisher = "Canonical"
    offer     = "UbuntuServer"
    sku       = "18.04-LTS"
    version   = "latest"
  }
  disable_password_authentication = false
  identity {
    type = "SystemAssigned"
  }
  computer_name = "testvm"
}


resource "google_compute_subnetwork" "subnet_gcp" {
  name                     = "subnet"
  ip_cidr_range            = "10.0.2.0/24"
  network                  = google_compute_network.example_vn_gcp.id
  private_ip_google_access = true
  provider                 = "google.europe-west1"
  project                  = "multy-project"
}

resource "google_compute_instance" "vm_gcp" {
  name         = "test-vm"
  machine_type = "e2-medium"
  zone         = "europe-west1-c"
  tags         = ["subnet-subnet"]
  boot_disk {
    initialize_params {
      image = "ubuntu-os-cloud/ubuntu-1804-lts"
    }
  }
  network_interface {
    subnetwork = google_compute_subnetwork.subnet_gcp.self_link
  }
  metadata = { "user-data" = "echo 'Hello World'" }
  provider = "google.europe-west1"
  project  = "multy-project"
}
resource "google_compute_network" "example_vn_gcp" {
  name                            = "example_gcp"
  routing_mode                    = "REGIONAL"
  description                     = "Managed by Multy"
  auto_create_subnetworks         = false
  delete_default_routes_on_create = true
  provider                        = "google.europe-west1"
  project                         = "multy-project"
}
resource "google_compute_instance" "vm2_gcp" {
  name         = "test-vm"
  machine_type = "e2-micro"
  zone         = "europe-west1-c"
  tags         = ["subnet-subnet"]
  boot_disk {
    initialize_params {
      image = "debian-cloud/debian-11"
    }
  }
  network_interface {
    subnetwork = google_compute_subnetwork.subnet_gcp.self_link
  }
  metadata = {}
  provider = "google.europe-west1"
  project  = "multy-project"
}
provider "google" {
  region = "europe-west1"
  alias  = "europe-west1"
}

provider "aws" {
  region = "eu-west-1"
  alias  = "eu-west-1"
}


provider "azurerm" {
  features {
  }
}

